@@ -262,7 +262,7 @@ smithfull <- function(data, coord, start, fit.marge = FALSE, iso = TRUE,
 
     else {
         std.err.type <- "yes"
-        var.cov <- ihessian %*% var.score %*% ihessian / n.obs
+        var.cov <- ihessian %*% var.score %*% ihessian
         std.err <- diag(var.cov)
 
         std.idx <- which(std.err <= 0)
@@ -758,7 +758,7 @@ PACKAGE = 'SpatialExtremes', NAOK = TRUE)$dns"))
 
     else{
         std.err.type <- "yes"
-        var.cov <- ihessian %*% var.score %*% ihessian / n.obs
+        var.cov <- ihessian %*% var.score %*% ihessian
         std.err <- diag(var.cov)
 
         std.idx <- which(std.err <= 0)
