@@ -12,9 +12,9 @@ void extremaltfull(int *covmod, double *data, double *dist, int *nSite, int *nOb
   const int nPairs = *nSite * (*nSite - 1) / 2;
   int i;
 
-  double *jac = (double *)R_alloc(*nSite * *nObs, sizeof(double)),
-    *rho = (double *)R_alloc(nPairs, sizeof(double)),
-    *frech = (double *)R_alloc(*nSite * *nObs, sizeof(double));
+  double *jac = malloc(*nSite * *nObs * sizeof(double)),
+    *rho = malloc(nPairs * sizeof(double)),
+    *frech = malloc(*nSite * *nObs * sizeof(double));
 
   //Some preliminary steps: Valid points?
   if (*fitmarge){
@@ -88,6 +88,8 @@ void extremaltfull(int *covmod, double *data, double *dist, int *nSite, int *nOb
       *dns = lplikextremalt(data, rho, *df, jac, *nObs, *nSite);
   }
 
+
+  free(jac); free(rho); free(frech);
   return;
 }
 
@@ -111,14 +113,16 @@ void extremaltdsgnmat(int *covmod, double *data, double *dist, int *nSite, int *
 
   const int nPairs = *nSite * (*nSite - 1) / 2;
   int flag = usetempcov[0] + usetempcov[1] + usetempcov[2];
-  double *trendlocs, *trendscales, *trendshapes;
 
-  double *jac = (double *)R_alloc(*nSite * *nObs, sizeof(double)),
-    *rho = (double *)R_alloc(nPairs, sizeof(double)),
-    *locs = (double *)R_alloc(*nSite, sizeof(double)),
-    *scales = (double *)R_alloc(*nSite, sizeof(double)),
-    *shapes = (double *)R_alloc(*nSite, sizeof(double)),
-    *frech = (double *)R_alloc(*nSite * *nObs, sizeof(double));
+  double *trendlocs = malloc(*nObs * sizeof(double)),
+    *trendscales = malloc(*nObs * sizeof(double)),
+    *trendshapes = malloc(*nObs * sizeof(double)),
+    *jac = malloc(*nSite * *nObs * sizeof(double)),
+    *rho = malloc(nPairs * sizeof(double)),
+    *locs = malloc(*nSite * sizeof(double)),
+    *scales = malloc(*nSite * sizeof(double)),
+    *shapes = malloc(*nSite * sizeof(double)),
+    *frech = malloc(*nSite * *nObs * sizeof(double));
 
   if (*df <= 0){
     *dns = (1 - *df) * (1 - *df) * MINF;
@@ -162,17 +166,12 @@ void extremaltdsgnmat(int *covmod, double *data, double *dist, int *nSite, int *
 		       *nSite, *nloccoeff, *nscalecoeff, *nshapecoeff, locs, scales, shapes);
 
   if (flag){
-    int i, j;
-    trendlocs = (double *)R_alloc(*nObs, sizeof(double));
-    trendscales = (double *)R_alloc(*nObs, sizeof(double));
-    trendshapes = (double *)R_alloc(*nObs, sizeof(double));
-
     dsgnmat2temptrend(tempdsgnmatloc, tempdsgnmatscale, tempdsgnmatshape, tempcoeffloc,
 		      tempcoeffscale, tempcoeffshape, *nSite, *nObs, usetempcov, *ntempcoeffloc,
 		      *ntempcoeffscale, *ntempcoeffshape, trendlocs, trendscales, trendshapes);
 
-    for (i=*nSite;i--;)
-      for (j=*nObs;j--;)
+    for (int i=*nSite;i--;)
+      for (int j=*nObs;j--;)
 	if (((scales[i] + trendscales[j]) <= 0) || ((shapes[i] + trendshapes[j]) <= -1)){
 	  *dns = MINF;
 	  return;
@@ -238,5 +237,7 @@ void extremaltdsgnmat(int *covmod, double *data, double *dist, int *nSite, int *
     *dns -= penalization(temppenmatshape, tempcoeffshape, *temppenaltyshape, *ntempcoeffshape,
 			 *nppartempcoeffshape);
 
+  free(trendlocs); free(trendscales); free(trendshapes); free(jac); free(rho); free(locs);
+  free(scales); free(shapes); free(frech);
   return;
 }
