@@ -10,16 +10,10 @@ void geomgaussfull(int *covmod, double *data, double *dist, int *nSite,
   //log-likelihood
   
   const int nPairs = *nSite * (*nSite - 1) / 2;
-  int i;
-  double *jac, *rho, *frech;
-
-  jac = (double *)R_alloc(*nSite * *nObs, sizeof(double));
-  rho = (double *)R_alloc(nPairs, sizeof(double));
-  frech = (double *)R_alloc(*nSite * *nObs, sizeof(double));
 
   //Some preliminary steps: Valid points?
   if (*fitmarge){
-    for (i=0;i<*nSite;i++){
+    for (int i=0;i<*nSite;i++){
       if ((scales[i] <= 0) || (shapes[i] <= -1)){
 	*dns = MINF;
 	return;
@@ -31,21 +25,29 @@ void geomgaussfull(int *covmod, double *data, double *dist, int *nSite,
     *dns = *nugget * *nugget * MINF;
     return;
   }
+
+   double *jac = malloc(*nSite * *nObs * sizeof(double)),
+    *rho = malloc(nPairs * sizeof(double)),
+     *frech = malloc(*nSite * *nObs * sizeof(double));
    
   //Stage 0: Compute the covariance at each location
   *dns = geomCovariance(dist, nPairs, *dim, *covmod, *sigma2, *sigma2Bound,
 			*nugget, *range, *smooth, *smooth2, rho);
 
-  if (*dns != 0.0)
+  if (*dns != 0.0){
+    free(jac); free(rho); free(frech);
     return;
+  }
     
   //Stage 1: Transformation to unit Frechet
   if (*fitmarge){
     *dns = gev2frech(data, *nObs, *nSite, locs, scales, shapes,
 		     jac, frech);
 
-    if (*dns != 0.0)
+    if (*dns != 0.0){
+      free(jac); free(rho); free(frech);
       return;
+    }
     
     if (*weighted)
       *dns = wlpliksmith(frech, rho, jac, *nObs, *nSite, weights);
@@ -55,7 +57,7 @@ void geomgaussfull(int *covmod, double *data, double *dist, int *nSite,
   }
     
   else {
-    for (i=(*nSite * *nObs);i--;)
+    for (int i=(*nSite * *nObs);i--;)
       jac[i] = 0;
    
     if (*weighted)
@@ -68,6 +70,7 @@ void geomgaussfull(int *covmod, double *data, double *dist, int *nSite,
   if (!R_FINITE(*dns))
     *dns = MINF;
 
+  free(jac); free(rho); free(frech);
   return;
 
 }
@@ -92,53 +95,58 @@ void geomgaussdsgnmat(int *covmod, double *data, double *dist, int *nSite, int *
   
   const int nPairs = *nSite * (*nSite - 1) / 2;
   int flag = usetempcov[0] + usetempcov[1] + usetempcov[2];
-  double *jac, *rho, *locs, *scales, *shapes, *frech, *trendlocs, *trendscales, *trendshapes;
 
-  jac = (double *)R_alloc(*nObs * *nSite, sizeof(double));
-  rho = (double *)R_alloc(nPairs, sizeof(double));
-  locs = (double *)R_alloc(*nSite, sizeof(double));
-  scales = (double *)R_alloc(*nSite, sizeof(double));
-  shapes = (double *)R_alloc(*nSite, sizeof(double));
-  frech = (double *)R_alloc(*nObs * *nSite, sizeof(double));
-  
   if (*nugget >= 1){
     *dns = *nugget * *nugget * MINF;
     return;
   }
 
   //Stage 1: Compute the covariance at each location
+  double *rho = malloc(nPairs * sizeof(double));
   *dns = geomCovariance(dist, nPairs, *dim, *covmod, *sigma2, *sigma2Bound, *nugget, *range,
 			*smooth, *smooth2, rho);
 
-  if (*dns != 0.0)
+  if (*dns != 0.0){
+    free(rho);
     return;
+  }
     
+  double *locs = malloc(*nSite * sizeof(double)),
+    *scales = malloc(*nSite * sizeof(double)),
+    *shapes = malloc(*nSite * sizeof(double)),
+    *trendlocs = malloc(*nObs * sizeof(double)),
+    *trendscales = malloc(*nObs * sizeof(double)),
+    *trendshapes = malloc(*nObs * sizeof(double));
+
   //Stage 2: Compute the GEV parameters using the design matrix
   *dns = dsgnmat2Param(locdsgnmat, scaledsgnmat, shapedsgnmat, loccoeff, scalecoeff, shapecoeff,
 		       *nSite, *nloccoeff, *nscalecoeff, *nshapecoeff, locs, scales, shapes);
 
   if (flag){
-    int i, j;
-    trendlocs = (double *)R_alloc(*nObs, sizeof(double));
-    trendscales = (double *)R_alloc(*nObs, sizeof(double));
-    trendshapes = (double *)R_alloc(*nObs, sizeof(double));
-
     dsgnmat2temptrend(tempdsgnmatloc, tempdsgnmatscale, tempdsgnmatshape, tempcoeffloc,
 		      tempcoeffscale, tempcoeffshape, *nSite, *nObs, usetempcov, *ntempcoeffloc,
 		      *ntempcoeffscale, *ntempcoeffshape, trendlocs, trendscales, trendshapes);
 
-    for (i=*nSite;i--;)
-      for (j=*nObs;j--;)
+    for (int i=*nSite;i--;)
+      for (int j=*nObs;j--;)
 	if (((scales[i] + trendscales[j]) <= 0) || ((shapes[i] + trendshapes[j]) <= -1)){
 	  *dns = MINF;
+	  free(locs); free(scales); free(shapes); free(trendlocs); free(trendscales);
+	  free(trendshapes);
 	  return;
 	}
   }
 
-  else if (*dns != 0.0)
+  else if (*dns != 0.0){
+    free(rho); free(locs); free(scales); free(shapes); free(trendlocs); free(trendscales);
+    free(trendshapes);
     return;
+  }
 
   //Stage 3: Transformation to unit Frechet
+  double *jac = malloc(*nObs * *nSite * sizeof(double)),
+    *frech = malloc(*nObs * *nSite * sizeof(double));
+
   if (flag)
     *dns = gev2frechTrend(data, *nObs, *nSite, locs, scales, shapes, trendlocs, trendscales,
 			  trendshapes, jac, frech);
@@ -146,8 +154,11 @@ void geomgaussdsgnmat(int *covmod, double *data, double *dist, int *nSite, int *
   else
     *dns = gev2frech(data, *nObs, *nSite, locs, scales, shapes, jac, frech);
 
-  if (*dns != 0.0)
+  if (*dns != 0.0){
+    free(rho); free(locs); free(scales); free(shapes); free(trendlocs); free(trendscales);
+    free(trendshapes); free(jac); free(frech);
     return;
+  }
   
   if (*weighted)
     *dns = wlpliksmith(frech, rho, jac, *nObs, *nSite, weights);
@@ -181,6 +192,8 @@ void geomgaussdsgnmat(int *covmod, double *data, double *dist, int *nSite, int *
     *dns -= penalization(temppenmatshape, tempcoeffshape, *temppenaltyshape, *ntempcoeffshape,
 			 *nppartempcoeffshape);
 
+  free(rho); free(locs); free(scales); free(shapes); free(trendlocs); free(trendscales);
+  free(trendshapes); free(jac); free(frech);
   return;
   
 }
